@@ -5,8 +5,15 @@ let f x =
 
 let test n = 
   let cs = Gsl_cheb.make 40 in
-  let gslfun = f in
-  Gsl_cheb.init cs gslfun 0. 1. ;
+  Gsl_cheb.init cs f 0. 1. ;
+  begin
+    let coefs = Gsl_cheb.coefs cs in
+    Printf.printf "coefs = [" ;
+    for i=0 to 40 do
+      Printf.printf " %f;" coefs.(i)
+    done ;
+    Printf.printf " ]\n"
+  end ;
   for i=0 to pred n do
     let x = float i /. float n in
     let r10 = Gsl_cheb.eval cs ~order:10 x in
