@@ -30,7 +30,7 @@ let y = Array.init 10
     (fun i -> float i +. cos (float (i*i)))
 
 let _ = 
-  let i = Gsl_interp.make Gsl_interp.CSPLINE x y in
+  let i = Gsl_interp.make_interp Gsl_interp.CSPLINE x y in
   let oc = Unix.open_process_out "graph -T X" in
   print_data oc i ;
   print_interp oc i ;
