@@ -47,8 +47,10 @@ exception Gsl_exn of (errno * string)
 
 external raise_caml_exn : bool -> unit = "ml_gsl_error_init"
 
+let _ = 
+  Callback.register_exception "mlgsl_exn" (Gsl_exn (CONTINUE, ""))
+
 let init () = 
-  Callback.register_exception "mlgsl_exn" (Gsl_exn (CONTINUE, "")) ;
   raise_caml_exn true
 
 let uninit () = 
