@@ -2,6 +2,8 @@
 (* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
+(** Fast Fourier Transforms *)
+
 open Gsl_complex
 
 exception Wrong_layout
@@ -72,11 +74,19 @@ module Complex :
   sig
     type workspace
     type wavetable
-    type direction = | Backward | Forward
+    type direction = Forward | Backward
 
     val make_workspace : int -> workspace
     val make_wavetable : int -> wavetable
 
+    external forward :
+      ?stride:int -> complex_array -> wavetable -> workspace -> unit
+      = "ml_gsl_fft_complex_forward"
+
+    external forward_rad2 : 
+      ?dif:bool -> ?stride:int -> complex_array -> unit
+      = "ml_gsl_fft_complex_rad2_forward"
+
     external transform :
       ?stride:int -> complex_array -> wavetable -> workspace -> direction -> unit
       = "ml_gsl_fft_complex_transform"
