@@ -5,7 +5,7 @@
 (** Histograms *)
 
 (** The histogram type *)
-type t = { 
+type t = private { 
     n     : int;  (** number of histogram bins *)
     range : float array; (** ranges of the bins ; n+1 elements *)
     bin   : float array; (** counts for each bin ; n elements *)
@@ -59,7 +59,7 @@ external shift : t -> float -> unit = "ml_gsl_histogram_shift"
 
 (** {3 Resampling} *)
 
-type histo_pdf = {
+type histo_pdf = private {
   pdf_n : int;
   pdf_range : float array;
   pdf_sum : float array;
