@@ -13,12 +13,14 @@ type interp_type =
   | AKIMA
   | AKIMA_PERIODIC
 
-external alloc : interp_type -> int -> t 
+external _alloc : interp_type -> int -> t 
     = "ml_gsl_interp_alloc"
-
-external free : t -> unit
+external _free : t -> unit
     = "ml_gsl_interp_free"
-
+let make t s =
+  let i = _alloc t s in
+  Gc.finalise _free i ;
+  i
 external _init : t -> float array -> float array -> int -> unit
     = "ml_gsl_interp_init"
 
@@ -35,12 +37,14 @@ external name : t -> string
 external min_size : t -> int
     = "ml_gsl_interp_min_size"
 
-external accel_alloc : unit -> accel
+external _accel_alloc : unit -> accel
     = "ml_gsl_interp_accel_alloc"
-
-external accel_free : accel -> unit
+external _accel_free : accel -> unit
     = "ml_gsl_interp_accel_free"
-
+let make_accel () =
+  let a = _accel_alloc () in
+  Gc.finalise _accel_free a ;
+  a
 external i_eval : t -> float array -> float array 
   -> float -> accel -> float
       = "ml_gsl_interp_eval"
@@ -68,18 +72,18 @@ type interp = {
     i_type : interp_type ;
   }
 
-let make i_type x y =
+let make_interp i_type x y =
   let len = Array.length x in
   let ly = Array.length y in
   if len <> ly
   then invalid_arg "Gsl_interp.make" ;
-  let t = alloc i_type len in
-  let a = accel_alloc () in
+  let t = _alloc i_type len in
+  let a = _accel_alloc () in
+  let v = { interp=t; accel = a ;
+    xa=x; ya=y; size=len; i_type=i_type } in
+  Gc.finalise (fun v -> _free v.interp ; _accel_free v.accel) v ;
   init t x y ;
-  Gc.finalise free t ;
-  Gc.finalise accel_free a ;
-  { interp=t; accel = a ;
-    xa=x; ya=y; size=len; i_type=i_type }
+  v
 
 let eval interp x =
   i_eval interp.interp interp.xa interp.ya x interp.accel
