@@ -14,12 +14,7 @@ type interp_type =
   | AKIMA
   | AKIMA_PERIODIC
 
-external alloc : interp_type -> int -> t 
-    = "ml_gsl_interp_alloc"
-
-external free : t -> unit
-    = "ml_gsl_interp_free"
-
+val make : interp_type -> int -> t 
 val init : t -> float array -> float array -> unit
 
 external name : t -> string 
@@ -28,11 +23,7 @@ external name : t -> string
 external min_size : t -> int
     = "ml_gsl_interp_min_size"
 
-external accel_alloc : unit -> accel
-    = "ml_gsl_interp_accel_alloc"
-
-external accel_free : accel -> unit
-    = "ml_gsl_interp_accel_free"
+val make_accel : unit -> accel
 
 external i_eval : t -> float array -> float array 
   -> float -> accel -> float
@@ -62,7 +53,7 @@ type interp = {
     i_type : interp_type ;
   }
 
-val make : interp_type -> float array -> float array -> interp
+val make_interp : interp_type -> float array -> float array -> interp
 
 val eval : interp -> float -> float
 
