@@ -7,15 +7,17 @@ open Gsl_fun
 
 (* PLAIN algorithm *)
 type plain_state
-
-external alloc_plain : int -> plain_state
+external _alloc_plain : int -> plain_state
     = "ml_gsl_monte_plain_alloc"
-
+external _free_plain : plain_state -> unit
+    = "ml_gsl_monte_plain_free"
+let make_plain_state s =
+  let state = _alloc_plain s in
+  Gc.finalise _free_plain state ;
+  state
 external init_plain : plain_state -> unit
     = "ml_gsl_monte_plain_init"
 
-external free_plain : plain_state -> unit
-    = "ml_gsl_monte_plain_free"
 
 external integrate_plain : monte_fun -> lo:float array -> up:float array ->
   int -> Gsl_rng.t -> plain_state -> Gsl_fun.result
@@ -32,14 +34,17 @@ type miser_params = {
     dither        : float ;             (* 0. *)
   } 
 
-external alloc_miser : int -> miser_state
+external _alloc_miser : int -> miser_state
     = "ml_gsl_monte_miser_alloc"
-
+external _free_miser : miser_state -> unit
+    = "ml_gsl_monte_miser_free"
+let make_miser_state s =
+  let state = _alloc_miser s in
+  Gc.finalise _free_miser state ;
+  state
 external init_miser : miser_state -> unit
     = "ml_gsl_monte_miser_init"
 
-external free_miser : miser_state -> unit
-    = "ml_gsl_monte_miser_free"
 
 external integrate_miser : monte_fun -> lo:float array -> up:float array ->
   int -> Gsl_rng.t -> miser_state -> Gsl_fun.result
@@ -69,15 +74,17 @@ type vegas_params = {
     ostream       : out_channel option ;  (* stdout *)
   } 
 
-external alloc_vegas : int -> vegas_state
+external _alloc_vegas : int -> vegas_state
     = "ml_gsl_monte_vegas_alloc"
-
+external _free_vegas : vegas_state -> unit
+    = "ml_gsl_monte_vegas_free"
+let make_vegas_state s =
+  let state = _alloc_vegas s in
+  Gc.finalise _free_vegas state ;
+  state
 external init_vegas : vegas_state -> unit
     = "ml_gsl_monte_vegas_init"
 
-external free_vegas : vegas_state -> unit
-    = "ml_gsl_monte_vegas_free"
-
 external integrate_vegas : monte_fun -> lo:float array -> up:float array ->
   int -> Gsl_rng.t -> vegas_state -> Gsl_fun.result
     = "ml_gsl_monte_vegas_integrate_bc" "ml_gsl_monte_vegas_integrate"
@@ -101,19 +108,16 @@ type kind =
 
 let integrate kind f ~lo ~up calls rng =
   let dim = Array.length lo in
+  let with_state alloc free integ =
+    let state = alloc dim in
+    try 
+      let res = integ f ~lo ~up calls rng state in
+      free state ; res
+    with exn -> free state ; raise exn in
   match kind with
   | PLAIN ->
-      let state = alloc_plain dim in
-      let res = integrate_plain f ~lo ~up calls rng state in
-      free_plain state ;
-      res
+      with_state _alloc_plain _free_plain integrate_plain
   | MISER ->
-      let state = alloc_miser dim in
-      let res = integrate_miser f ~lo ~up calls rng state in
-      free_miser state ;
-      res
+      with_state _alloc_miser _free_miser integrate_miser
   | VEGAS ->
-      let state = alloc_vegas dim in
-      let res = integrate_vegas f ~lo ~up calls rng state in
-      free_vegas state ;
-      res
+      with_state _alloc_vegas _free_vegas integrate_vegas
