@@ -23,12 +23,9 @@ val integrate : kind -> monte_fun -> lo:float array -> up:float array ->
 (** {4 PLAIN algorithm} *)
 
 type plain_state
-external alloc_plain : int -> plain_state
-    = "ml_gsl_monte_plain_alloc"
+val make_plain_state : int -> plain_state
 external init_plain : plain_state -> unit
     = "ml_gsl_monte_plain_init"
-external free_plain : plain_state -> unit
-    = "ml_gsl_monte_plain_free"
 external integrate_plain :
   monte_fun ->
   lo:float array ->
@@ -46,12 +43,9 @@ type miser_params = {
   miser_alpha             : float;
   dither                  : float;
 } 
-external alloc_miser : int -> miser_state
-    = "ml_gsl_monte_miser_alloc"
+val make_miser_state : int -> miser_state
 external init_miser : miser_state -> unit
     = "ml_gsl_monte_miser_init"
-external free_miser : miser_state -> unit
-    = "ml_gsl_monte_miser_free"
 external integrate_miser :
   monte_fun ->
   lo:float array ->
@@ -82,12 +76,9 @@ type vegas_params = {
     ostream       : out_channel option ;
   } 
 
-external alloc_vegas : int -> vegas_state
-    = "ml_gsl_monte_vegas_alloc"
+val make_vegas_state : int -> vegas_state
 external init_vegas : vegas_state -> unit
     = "ml_gsl_monte_vegas_init"
-external free_vegas : vegas_state -> unit
-    = "ml_gsl_monte_vegas_free"
 
 external integrate_vegas : monte_fun -> lo:float array -> up:float array ->
   int -> Gsl_rng.t -> vegas_state -> Gsl_fun.result
