@@ -20,6 +20,12 @@ external _linear : ?weight:vec -> x:mat -> y:vec -> c:vec -> cov:mat ->
       ws -> float
 	  = "ml_gsl_multifit_linear_bc" "ml_gsl_multifit_linear"
 
+external _linear_svd : 
+  ?weight:vec -> x:mat -> y:vec -> 
+  tol:float -> c:vec -> cov:mat -> 
+  ws -> int * float
+    = "ml_gsl_multifit_linear_svd_bc" "ml_gsl_multifit_linear_svd"
+
 let linear ?weight x y =
   let (n,p) = Gsl_vectmat.dims x in
   let dy = Gsl_vectmat.length y in
@@ -32,9 +38,15 @@ let linear ?weight x y =
   let c = Gsl_vector.create p in
   let cov = Gsl_matrix.create p p in
   let ws = alloc_ws n p in
-  let chisq = _linear ?weight ~x ~y ~c:(`V c) ~cov:(`M cov) ws in
-  free_ws ws ;
-  (c, cov, chisq)
+  try
+    let chisq = _linear ?weight ~x ~y ~c:(`V c) ~cov:(`M cov) ws in
+    free_ws ws ;
+    (c, cov, chisq)
+  with exn ->
+    free_ws ws ; raise exn
+
+external linear_est : x:vec -> c:vec -> cov:mat -> Gsl_fun.result
+    = "ml_gsl_multifit_linear_est"
 
 let fit_poly ?weight ~x ~y order =
   let n = Array.length y in
