@@ -2,6 +2,8 @@
 (* Copyright (©) 2002-2005 - Olivier Andrieu                *)
 (* distributed under the terms of the GPL version 2         *)
 
+(** Multi-parameter Least-Squares Fitting *)
+
 open Gsl_vectmat
 
 type ws
@@ -13,10 +15,19 @@ external _linear :
   c:vec -> cov:mat -> ws -> float
   = "ml_gsl_multifit_linear_bc" "ml_gsl_multifit_linear"
 
+external _linear_svd :
+  ?weight:vec ->
+  x:mat -> y:vec -> tol:float ->
+  c:vec -> cov:mat -> ws -> int * float
+  = "ml_gsl_multifit_linear_svd_bc" "ml_gsl_multifit_linear_svd"
+
 val linear :
   ?weight:vec -> mat -> vec -> 
     Gsl_vector.vector * Gsl_matrix.matrix * float
 
+external linear_est : x:vec -> c:vec -> cov:mat -> Gsl_fun.result
+    = "ml_gsl_multifit_linear_est"
+
 val fit_poly : 
     ?weight:float array -> x:float array -> y:float array -> int ->
       float array * float array array * float
