@@ -38,7 +38,11 @@ external _solve    : poly -> ws -> complex_array -> unit
 let solve poly = 
   let n = Array.length poly in
   let ws = _alloc_ws n in
-  let sol = Array.make (2*(n-1)) 0. in
-  _solve poly ws sol ;
-  _free_ws ws ;
-  sol
+  try
+    let sol = Array.make (2*(n-1)) 0. in
+    _solve poly ws sol ;
+    _free_ws ws ;
+    sol
+  with exn ->
+    _free_ws ws ; raise exn
+
