@@ -4,7 +4,7 @@
 
 (** Vector of floats implemented with a [float array] *)
 
-type double_vector_flat = {
+type double_vector_flat = private {
     data : float array;
     off : int;
     len : int;
