@@ -143,3 +143,85 @@ CAMLprim value ml_gsl_eigen_hermv_sort(value E, value sort)
   gsl_eigen_hermv_sort(&v_EVAL, &m_EVEC, eigen_sort_type[ Int_val(sort) ]);
   return Val_unit;
 }
+
+
+/* Real Nonsymmetrix Matrices */
+CAMLprim value ml_gsl_eigen_nonsymm_alloc(value n)
+{
+  value v;
+  gsl_eigen_nonsymm_workspace *ws = gsl_eigen_nonsymm_alloc(Int_val(n));
+  Abstract_ptr(v, ws);
+  return v;
+}
+
+#define NONSYMM_WS_val(v) ((gsl_eigen_nonsymm_workspace *)Field(v, 0))
+
+ML1(gsl_eigen_nonsymm_free, NONSYMM_WS_val, Unit)
+
+CAMLprim value ml_gsl_eigen_nonsymm(value A, value EVAL, value ws)
+{
+  _DECLARE_MATRIX(A);
+  _DECLARE_COMPLEX_VECTOR(EVAL);
+  _CONVERT_MATRIX(A);
+  _CONVERT_COMPLEX_VECTOR(EVAL);
+  gsl_eigen_nonsymm(&m_A, &v_EVAL, NONSYMM_WS_val(ws));
+  return Val_unit;
+}
+
+CAMLprim value ml_gsl_eigen_nonsymm_Z(value A, value EVAL, value Z, value ws)
+{
+  _DECLARE_MATRIX2(A,Z);
+  _DECLARE_COMPLEX_VECTOR(EVAL);
+  _CONVERT_MATRIX2(A,Z);
+  _CONVERT_COMPLEX_VECTOR(EVAL);
+  gsl_eigen_nonsymm_Z(&m_A, &v_EVAL, &m_Z, NONSYMM_WS_val(ws));
+  return Val_unit;
+}
+
+CAMLprim value ml_gsl_eigen_nonsymmv_alloc(value n)
+{
+  value v;
+  gsl_eigen_nonsymmv_workspace *ws = gsl_eigen_nonsymmv_alloc(Int_val(n));
+  Abstract_ptr(v, ws);
+  return v;
+}
+
+#define NONSYMMV_WS_val(v) ((gsl_eigen_nonsymmv_workspace *)Field(v, 0))
+
+ML1(gsl_eigen_nonsymmv_free, NONSYMMV_WS_val, Unit)
+
+CAMLprim value ml_gsl_eigen_nonsymmv(value A, value EVAL, value EVEC, value ws)
+{
+  _DECLARE_MATRIX(A);
+  _DECLARE_COMPLEX_VECTOR(EVAL);
+  _DECLARE_COMPLEX_MATRIX(EVEC);
+  _CONVERT_MATRIX(A);
+  _CONVERT_COMPLEX_VECTOR(EVAL);
+  _CONVERT_COMPLEX_MATRIX(EVEC);
+  gsl_eigen_nonsymmv(&m_A, &v_EVAL, &m_EVEC, NONSYMMV_WS_val(ws));
+  return Val_unit;
+}
+
+CAMLprim value ml_gsl_eigen_nonsymmv_Z(value A, value EVAL, value EVEC, value Z, value ws)
+{
+  _DECLARE_MATRIX2(A,Z);
+  _DECLARE_COMPLEX_VECTOR(EVAL);
+  _DECLARE_COMPLEX_MATRIX(EVEC);
+  _CONVERT_MATRIX2(A,Z);
+  _CONVERT_COMPLEX_VECTOR(EVAL);
+  _CONVERT_COMPLEX_MATRIX(EVEC);
+  gsl_eigen_nonsymmv_Z(&m_A, &v_EVAL, &m_EVEC, &m_Z, NONSYMMV_WS_val(ws));
+  return Val_unit;
+}
+
+CAMLprim value ml_gsl_eigen_nonsymmv_sort(value E, value sort)
+{
+  value EVAL = Field(E, 0);
+  value EVEC = Field(E, 1);
+  _DECLARE_COMPLEX_VECTOR(EVAL);
+  _DECLARE_COMPLEX_MATRIX(EVEC);
+  _CONVERT_COMPLEX_VECTOR(EVAL);
+  _CONVERT_COMPLEX_MATRIX(EVEC);
+  gsl_eigen_nonsymmv_sort(&v_EVAL, &m_EVEC, eigen_sort_type[ Int_val(sort) ]);
+  return Val_unit;
+}
