@@ -8,9 +8,6 @@
 #define TYPE(t) CONCAT2(t,BASE_TYPE)
 #define _DECLARE_BASE_TYPE(v) gsl_complex_float conv_##v
 #define _CONVERT_BASE_TYPE(v) GSL_SET_COMPLEX(&conv_##v,Double_field(v, 0), Double_field(v,1))
-#if __GNUC__ >= 3
-#define DECLARE_BASE_TYPE(v) _DECLARE_BASE_TYPE(v); _CONVERT_BASE_TYPE(v)
-#endif /* __GNUC__ */
 #define FUNCTION(a,b) CONCAT3(a,BASE_TYPE,b)
 
 #include "mlgsl_matrix.h"
