@@ -44,10 +44,11 @@ CAMLprim value ml_gsl_min_fminimizer_alloc(value t)
 
 CAMLprim value ml_gsl_min_fminimizer_set(value s, value f, value min, value lo, value up)
 {
+  CAMLparam1(s);
   Mparams_val(s)->closure = f;
   gsl_min_fminimizer_set(Minimizer_val(s), &(Mparams_val(s)->gslfun.gf), 
 			 Double_val(min), Double_val(lo), Double_val(up));
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_min_fminimizer_free(value s)
