@@ -76,6 +76,7 @@ CAMLprim value ml_gsl_monte_plain_free(value s)
 CAMLprim value ml_gsl_monte_plain_integrate(value fun, value xlo, value xup, 
 				   value calls, value rng, value state)
 {
+  CAMLparam2(rng, state);
   double result, abserr;
   size_t dim=Double_array_length(xlo);
   LOCALARRAY(double, c_xlo, dim); 
@@ -95,7 +96,7 @@ CAMLprim value ml_gsl_monte_plain_integrate(value fun, value xlo, value xup,
 			    Rng_val(rng),
 			    GSLPLAINSTATE_VAL(state),
 			    &result, &abserr);
-  return copy_two_double_arr(result, abserr);
+  CAMLreturn(copy_two_double_arr(result, abserr));
 }
 
 CAMLprim value ml_gsl_monte_plain_integrate_bc(value *argv, int argc)
@@ -150,6 +151,7 @@ CAMLprim value ml_gsl_monte_miser_free(value s)
 CAMLprim value ml_gsl_monte_miser_integrate(value fun, value xlo, value xup, 
 				   value calls, value rng, value state)
 {
+  CAMLparam2(rng, state);
   double result,abserr;
   size_t dim=Double_array_length(xlo);
   LOCALARRAY(double, c_xlo, dim); 
@@ -169,7 +171,7 @@ CAMLprim value ml_gsl_monte_miser_integrate(value fun, value xlo, value xup,
 			    Rng_val(rng),
 			    GSLMISERSTATE_VAL(state),
 			    &result, &abserr);
-  return copy_two_double_arr(result, abserr);
+  CAMLreturn(copy_two_double_arr(result, abserr));
 }
 
 CAMLprim value ml_gsl_monte_miser_integrate_bc(value *argv, int argc)
@@ -256,6 +258,7 @@ CAMLprim value ml_gsl_monte_vegas_free(value state)
 CAMLprim value ml_gsl_monte_vegas_integrate(value fun, value xlo, value xup, 
 				   value calls, value rng, value state)
 {
+  CAMLparam2(rng, state);
   double result,abserr;
   size_t dim=Double_array_length(xlo);
   LOCALARRAY(double, c_xlo, dim); 
@@ -275,7 +278,7 @@ CAMLprim value ml_gsl_monte_vegas_integrate(value fun, value xlo, value xup,
 			    Rng_val(rng),
 			    GSLVEGASSTATE_VAL(state),
 			    &result, &abserr);
-  return copy_two_double_arr(result, abserr);
+  CAMLreturn(copy_two_double_arr(result, abserr));
 }
 
 CAMLprim value ml_gsl_monte_vegas_integrate_bc(value *argv, int argc)
