@@ -53,12 +53,13 @@ CAMLprim value ml_gsl_multifit_fdfsolver_alloc(value type, value n, value p)
 
 CAMLprim value ml_gsl_multifit_fdfsolver_set(value S, value fun, value x)
 {
+  CAMLparam2(S, x);
   struct callback_params *p=CALLBACKPARAMS_VAL(S);
   _DECLARE_VECTOR(x);
   _CONVERT_VECTOR(x);
   p->closure = fun;
   gsl_multifit_fdfsolver_set(FDFSOLVER_VAL(S), &(p->gslfun.mffdf), &v_x);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multifit_fdfsolver_free(value S)
@@ -76,12 +77,13 @@ ML1(gsl_multifit_fdfsolver_iterate, FDFSOLVER_VAL, Unit)
 
 CAMLprim value ml_gsl_multifit_fdfsolver_position(value S, value x)
 {
+  CAMLparam2(S, x);
   gsl_vector *pos;
   _DECLARE_VECTOR(x);
   _CONVERT_VECTOR(x);
   pos=gsl_multifit_fdfsolver_position(FDFSOLVER_VAL(S));
   gsl_vector_memcpy(&v_x, pos);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multifit_fdfsolver_get_state(value solv, value xo, value fo, 
