@@ -22,6 +22,7 @@ static const gsl_multimin_fdfminimizer_type *fdfminimizer_of_value(value t)
     gsl_multimin_fdfminimizer_conjugate_fr,
     gsl_multimin_fdfminimizer_conjugate_pr,
     gsl_multimin_fdfminimizer_vector_bfgs,
+    gsl_multimin_fdfminimizer_vector_bfgs2,
     gsl_multimin_fdfminimizer_steepest_descent, } ;
   return minimizer_types[Int_val(t)];
 }
@@ -56,6 +57,7 @@ CAMLprim value ml_gsl_multimin_fdfminimizer_alloc(value type, value d)
 CAMLprim value ml_gsl_multimin_fdfminimizer_set(value S, value fun, value X,
 				       value step, value tol)
 {
+  CAMLparam2(S, X);
   struct callback_params *p=CALLBACKPARAMS_VAL(S);
   _DECLARE_VECTOR(X);
   _CONVERT_VECTOR(X);
@@ -63,7 +65,7 @@ CAMLprim value ml_gsl_multimin_fdfminimizer_set(value S, value fun, value X,
   gsl_multimin_fdfminimizer_set(GSLMULTIMINFDFMINIMIZER_VAL(S), 
 				&(p->gslfun.mmfdf), &v_X,
 				Double_val(step), Double_val(tol));
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multimin_fdfminimizer_free(value S)
@@ -151,13 +153,14 @@ CAMLprim value ml_gsl_multimin_fminimizer_alloc(value type, value d)
 CAMLprim value ml_gsl_multimin_fminimizer_set(value S, value fun, 
 				     value X, value step_size)
 {
+  CAMLparam3(S, X, step_size);
   struct callback_params *p=CALLBACKPARAMS_VAL(S);
   _DECLARE_VECTOR2(X,step_size);
   _CONVERT_VECTOR2(X,step_size);
   p->closure = fun;
   gsl_multimin_fminimizer_set(GSLMULTIMINFMINIMIZER_VAL(S), 
 			      &(p->gslfun.mmf), &v_X, &v_step_size);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multimin_fminimizer_free(value S)
