@@ -87,6 +87,7 @@ CAMLprim value ml_gsl_multiroot_fdfsolver_alloc(value type, value d)
 
 CAMLprim value ml_gsl_multiroot_fsolver_set(value S, value fun, value X)
 {
+  CAMLparam2(S, X);
   struct callback_params *p=CALLBACKPARAMS_VAL(S);
   _DECLARE_VECTOR(X);
   _CONVERT_VECTOR(X);
@@ -94,11 +95,12 @@ CAMLprim value ml_gsl_multiroot_fsolver_set(value S, value fun, value X)
   if(v_X.size != p->gslfun.mrf.n)
     GSL_ERROR("wrong number of dimensions for function", GSL_EBADLEN);
   gsl_multiroot_fsolver_set(GSLMULTIROOTSOLVER_VAL(S), &(p->gslfun.mrf), &v_X);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multiroot_fdfsolver_set(value S, value fun, value X)
 {
+  CAMLparam2(S,X);
   struct callback_params *p=CALLBACKPARAMS_VAL(S);
   _DECLARE_VECTOR(X);
   _CONVERT_VECTOR(X);
@@ -107,7 +109,7 @@ CAMLprim value ml_gsl_multiroot_fdfsolver_set(value S, value fun, value X)
     GSL_ERROR("wrong number of dimensions for function", GSL_EBADLEN);
   gsl_multiroot_fdfsolver_set(GSLMULTIROOTFDFSOLVER_VAL(S), 
 			      &(p->gslfun.mrfdf), &v_X);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multiroot_fsolver_free(value S)
@@ -136,22 +138,24 @@ ML1(gsl_multiroot_fdfsolver_iterate, GSLMULTIROOTFDFSOLVER_VAL, Unit)
 
 CAMLprim value ml_gsl_multiroot_fsolver_root(value S, value r)
 {
+  CAMLparam2(S,r);
   gsl_vector *root;
   _DECLARE_VECTOR(r);
   _CONVERT_VECTOR(r);
   root=gsl_multiroot_fsolver_root(GSLMULTIROOTSOLVER_VAL(S));
   gsl_vector_memcpy(&v_r, root);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multiroot_fdfsolver_root(value S, value r)
 {
+  CAMLparam2(S,r);
   gsl_vector *root;
   _DECLARE_VECTOR(r);
   _CONVERT_VECTOR(r);
   root=gsl_multiroot_fdfsolver_root(GSLMULTIROOTFDFSOLVER_VAL(S));
   gsl_vector_memcpy(&v_r, root);
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_multiroot_fsolver_get_state(value S, value ox, 
