@@ -1,5 +1,5 @@
 /* ocamlgsl - OCaml interface to GSL                        */
-/* Copyright () 2002 - Olivier Andrieu                     */
+/* Copyright (©) 2002-2005 - Olivier Andrieu                */
 /* distributed under the terms of the GPL version 2         */
 
 
@@ -17,7 +17,7 @@ static inline const gsl_qrng_type *qrngtype_val(value v)
 
 #define Qrng_val(v) (gsl_qrng *)Field((v), 0)
 
-value ml_gsl_qrng_alloc(value type, value dim)
+CAMLprim value ml_gsl_qrng_alloc(value type, value dim)
 {
   value r;
   Abstract_ptr(r, gsl_qrng_alloc(qrngtype_val(type), Int_val(dim)));
@@ -27,12 +27,12 @@ value ml_gsl_qrng_alloc(value type, value dim)
 ML1(gsl_qrng_free, Qrng_val, Unit)
 ML1(gsl_qrng_init, Qrng_val, Unit)
 
-value ml_gsl_qrng_dimension(value qrng)
+CAMLprim value ml_gsl_qrng_dimension(value qrng)
 {
   return Val_int((Qrng_val(qrng))->dimension);
 }
 
-value ml_gsl_qrng_get(value qrng, value x)
+CAMLprim value ml_gsl_qrng_get(value qrng, value x)
 {
   if(Double_array_length(x) != (Qrng_val(qrng))->dimension)
     GSL_ERROR("wrong array size", GSL_EBADLEN);
@@ -40,7 +40,7 @@ value ml_gsl_qrng_get(value qrng, value x)
   return Val_unit;
 }
 
-value ml_gsl_qrng_sample(value qrng)
+CAMLprim value ml_gsl_qrng_sample(value qrng)
 {
   gsl_qrng * q = Qrng_val(qrng);
   value arr = alloc(q->dimension * Double_wosize, Double_array_tag);
@@ -50,13 +50,13 @@ value ml_gsl_qrng_sample(value qrng)
 
 ML1(gsl_qrng_name, Qrng_val, copy_string)
 
-value ml_gsl_qrng_memcpy(value src, value dst)
+CAMLprim value ml_gsl_qrng_memcpy(value src, value dst)
 {
   gsl_qrng_memcpy(Qrng_val(dst), Qrng_val(src));
   return Val_unit;
 }
 
-value ml_gsl_qrng_clone(value qrng)
+CAMLprim value ml_gsl_qrng_clone(value qrng)
 {
   value r;
   Abstract_ptr(r, gsl_qrng_clone(Qrng_val(qrng))); 
