@@ -85,19 +85,21 @@ CAMLprim value ml_gsl_root_fdfsolver_alloc(value t)
 
 CAMLprim value ml_gsl_root_fsolver_set(value s, value f, value lo, value hi)
 {
+  CAMLparam1(s);
   struct callback_params *p=Fparams_val(s);
   p->closure=f;
   gsl_root_fsolver_set(Fsolver_val(s), &(p->gslfun.gf), 
 		       Double_val(lo), Double_val(hi));
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_root_fdfsolver_set(value s, value f, value r)
 {
+  CAMLparam1(s);
   struct callback_params *p=Fparams_val(s);
   p->closure=f;
   gsl_root_fdfsolver_set(FDFsolver_val(s), &(p->gslfun.gfdf), Double_val(r));
-  return Val_unit;
+  CAMLreturn(Val_unit);
 }
 
 CAMLprim value ml_gsl_root_fsolver_free(value s)
